==> qxcommon-1.0.06-sources.jar: cn/com/startai/qxcommon/busi/huadian/bean/HDGetTripDetailResp.java <==
package cn.com.startai.qxcommon.busi.huadian.bean;

import java.util.List;

import cn.com.startai.qxcommon.busi.huadian.HDCmd;
import cn.com.startai.qxcommon.protocol.QXBaseContent;

/**
 * Created by Robin on 2019/5/25.
 * 419109715@qq.com 彬影
 */
public class HDGetTripDetailResp extends QXBaseContent {


    private String userId;
    private String schedulingId;//排班id
    private List<DataBean> data;

    @Override
    public String toString() {
        return "HDGetTripDetailResp{" +
                "userId='" + userId + '\'' +
                ", schedulingId='" + schedulingId + '\'' +
                ", data=" + data +
                ", custom=" + custom +
                ", product=" + product +
                ", cmd=" + cmd +
                ", result=" + result +
                '}';
    }

    @Override
    public long getCmd() {
        return HDCmd.HD_GET_TRIP_RECORD;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getSchedulingId() {
        return schedulingId;
    }

    public void setSchedulingId(String schedulingId) {
        this.schedulingId = schedulingId;
    }

    public List<DataBean> getData() {
        return data;
    }

    public void setData(List<DataBean> data) {
        this.data = data;
    }

    public static class DataBean {
        /**
         * trainId : G1
         * endStation : 广州
         * startStation : 北京南
         * startTime :
         * endTime :
         */

        private String trainId;
        private String endStation;
        private String startStation;
        private String startTime;
        private String endTime;

        @Override
        public String toString() {
            return "DataBean{" +
                    "trainId='" + trainId + '\'' +
                    ", endStation='" + endStation + '\'' +
                    ", startStation='" + startStation + '\'' +
                    ", startTime='" + startTime + '\'' +
                    ", endTime='" + endTime + '\'' +
                    '}';
        }

        public String getTrainId() {
            return trainId;
        }

        public void setTrainId(String trainId) {
            this.trainId = trainId;
        }

        public String getEndStation() {
            return endStation;
        }

        public void setEndStation(String endStation) {
            this.endStation = endStation;
        }

        public String getStartStation() {
            return startStation;
        }

        public void setStartStation(String startStation) {
            this.startStation = startStation;
        }

        public String getStartTime() {
            return startTime;
        }

        public void setStartTime(String startTime) {
            this.startTime = startTime;
        }

        public String getEndTime() {
            return endTime;
        }

        public void setEndTime(String endTime) {
            this.endTime = endTime;
        }
    }
}

==> qxcommon-1.0.26-sources.jar: cn/com/startai/qxcommon/busi/huadian/bean/HDGetTripDetailResp.java <==
package cn.com.startai.qxcommon.busi.huadian.bean;

import java.io.Serializable;
import java.util.List;

import cn.com.startai.qxcommon.busi.huadian.HDCmd;
import cn.com.startai.qxcommon.protocol.QXBaseContent;

/**
 * Created by Robin on 2019/5/25.
 * 419109715@qq.com 彬影
 */
public class HDGetTripDetailResp extends QXBaseContent {


    private String userId;
    private String schedulingId;//排班id
    private List<DataBean> data;

    @Override
    public String toString() {
        return "HDGetTripDetailResp{" +
                "userId='" + userId + '\'' +
                ", schedulingId='" + schedulingId + '\'' +
                ", data=" + data +
                ", custom=" + custom +
                ", product=" + product +
                ", cmd=" + cmd +
                ", result=" + result +
                '}';
    }

    @Override
    public long getCmd() {
        return HDCmd.HD_GET_TRIP_RECORD;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getSchedulingId() {
        return schedulingId;
    }

    public void setSchedulingId(String schedulingId) {
        this.schedulingId = schedulingId;
    }

    public List<DataBean> getData() {
        return data;
    }

    public void setData(List<DataBean> data) {
        this.data = data;
    }

    public static class DataBean implements Serializable {
        /**
         * trainId : G1
         * endStation : 广州
         * startStation : 北京南
         * startTime :
         * endTime :
         */

        private String trainId;
        private String endStation;
        private String startStation;
        private String startTime;
        private String endTime;

        private int cashTotalMoney;
        private int noCashTotalMoney;
        private int refundTotalMoney;

        @Override
        public String toString() {
            return "DataBean{" +
                    "trainId='" + trainId + '\'' +
                    ", endStation='" + endStation + '\'' +
                    ", startStation='" + startStation + '\'' +
                    ", startTime='" + startTime + '\'' +
                    ", endTime='" + endTime + '\'' +
                    ", cashTotalMoney=" + cashTotalMoney +
                    ", noCashTotalMoney=" + noCashTotalMoney +
                    ", refundTotalMoney=" + refundTotalMoney +
                    '}';
        }

        public int getCashTotalMoney() {
            return cashTotalMoney;
        }

        public void setCashTotalMoney(int cashTotalMoney) {
            this.cashTotalMoney = cashTotalMoney;
        }

        public int getNoCashTotalMoney() {
            return noCashTotalMoney;
        }

        public void setNoCashTotalMoney(int noCashTotalMoney) {
            this.noCashTotalMoney = noCashTotalMoney;
        }

        public int getRefundTotalMoney() {
            return refundTotalMoney;
        }

        public void setRefundTotalMoney(int refundTotalMoney) {
            this.refundTotalMoney = refundTotalMoney;
        }

        public String getTrainId() {
            return trainId;
        }

        public void setTrainId(String trainId) {
            this.trainId = trainId;
        }

        public String getEndStation() {
            return endStation;
        }

        public void setEndStation(String endStation) {
            this.endStation = endStation;
        }

        public String getStartStation() {
            return startStation;
        }

        public void setStartStation(String startStation) {
            this.startStation = startStation;
        }

        public String getStartTime() {
            return startTime;
        }

        public void setStartTime(String startTime) {
            this.startTime = startTime;
        }

        public String getEndTime() {
            return endTime;
        }

        public void setEndTime(String endTime) {
            this.endTime = endTime;
        }
    }
}
